@@ -17,7 +17,7 @@
  */
 package org.apache.drill.exec.store.parquet2;
 
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.drill.common.exceptions.ExecutionSetupException;
 import org.apache.drill.common.expression.PathSegment;
 import org.apache.drill.common.expression.SchemaPath;
@@ -37,7 +37,7 @@ import org.apache.drill.exec.store.parquet.compression.DrillCompressionCodecFact
 import org.apache.drill.exec.vector.AllocationHelper;
 import org.apache.drill.exec.vector.NullableIntVector;
 import org.apache.drill.exec.vector.ValueVector;
-import org.apache.drill.shaded.guava.com.google.common.base.Preconditions;
+import com.google.common.base.Preconditions;
 import org.apache.parquet.column.ColumnDescriptor;
 import org.apache.parquet.compression.CompressionCodecFactory;
 import org.apache.parquet.hadoop.ColumnChunkIncReadStore;
@@ -55,7 +55,6 @@ import org.apache.parquet.schema.Types;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
-import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
@@ -417,13 +416,9 @@ public class DrillParquetReader extends CommonParquetRecordReader {
     recordReader = null;
     recordMaterializer = null;
     nullFilledVectors = null;
-    try {
-      if (pageReadStore != null) {
-        pageReadStore.close();
-        pageReadStore = null;
-      }
-    } catch (IOException e) {
-      logger.warn("Failure while closing PageReadStore", e);
+    if (pageReadStore != null) {
+      pageReadStore.close();
+      pageReadStore = null;
     }
   }
 
